@@ -7,6 +7,7 @@ irrespective of what has been deposited with the U.S. Copyright Office.
 
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package clustermgmt
 
@@ -17,17 +18,19 @@ import (
 	"time"
 
 	"github.com/golang/glog"
-	"github.com/stolostron/search-aggregator/pkg/config"
+	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
+	agentv1 "github.com/open-cluster-management/klusterlet-addon-controller/pkg/apis/agent/v1"
+	clusterv1beta1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/cluster/v1beta1"
+	"github.com/open-cluster-management/search-aggregator/pkg/config"
+	db "github.com/open-cluster-management/search-aggregator/pkg/dbconnector"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/client-go/dynamic/dynamicinformer"
 	"k8s.io/client-go/tools/cache"
-
-	db "github.com/stolostron/search-aggregator/pkg/dbconnector"
-	clusterv1beta1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
-	clusterv1 "open-cluster-management.io/api/cluster/v1"
 )
 
+const apigroup = "internal.open-cluster-management.io"
+
 // Watches ManagedCluster and ManagedClusterInfo objects and updates
 // the search graph with a Cluster pseudo node.
 func WatchClusters() {
@@ -39,10 +42,12 @@ func WatchClusters() {
 	// Create GVR for ManagedCluster and ManagedClusterInfo
 	managedClusterGvr, _ := schema.ParseResourceArg("managedclusters.v1.cluster.open-cluster-management.io")
 	managedClusterInfoGvr, _ := schema.ParseResourceArg("managedclusterinfos.v1beta1.internal.open-cluster-management.io")
+	klusterletAddonConfigGvr, _ := schema.ParseResourceArg("klusterletaddonconfigs.v1.agent.open-cluster-management.io")
 
 	//Create Informers for ManagedCluster and ManagedClusterInfo
 	managedClusterInformer := dynamicFactory.ForResource(*managedClusterGvr).Informer()
 	managedClusterInfoInformer := dynamicFactory.ForResource(*managedClusterInfoGvr).Informer()
+	klusterletAddonConfigInformer := dynamicFactory.ForResource(*klusterletAddonConfigGvr).Informer()
 
 	// Create handlers for events
 	handlers := cache.ResourceEventHandlerFuncs{
@@ -60,10 +65,12 @@ func WatchClusters() {
 	// Add Handlers to both Informers
 	managedClusterInformer.AddEventHandler(handlers)
 	managedClusterInfoInformer.AddEventHandler(handlers)
+	klusterletAddonConfigInformer.AddEventHandler(handlers)
 
 	// Periodically check if the ManagedCluster/ManagedClusterInfo resource exists
 	go stopAndStartInformer("cluster.open-cluster-management.io/v1", managedClusterInformer)
 	go stopAndStartInformer("internal.open-cluster-management.io/v1beta1", managedClusterInfoInformer)
+	go stopAndStartInformer("agent.open-cluster-management.io/v1", klusterletAddonConfigInformer)
 }
 
 // Stop and Start informer according to Rediscover Rate
@@ -125,6 +132,13 @@ func processClusterUpsert(obj interface{}) {
 			glog.Warning("Failed to Unmarshal ManagedclusterInfo", err)
 		}
 		resource = transformManagedClusterInfo(&managedClusterInfo)
+	case "KlusterletAddonConfig":
+		klusterletAddonConfig := agentv1.KlusterletAddonConfig{}
+		err = json.Unmarshal(j, &klusterletAddonConfig)
+		if err != nil {
+			glog.Warning("Failed to Unmarshal KlusterletAddonConfig", err)
+		}
+		resource = transformKlusterletAddonConfig(&klusterletAddonConfig)
 	default:
 		glog.Warning("ClusterWatch received unknown kind.", obj.(*unstructured.Unstructured).GetKind())
 	}
@@ -165,9 +179,33 @@ func isClusterMissing(err error) bool {
 	return strings.Contains(err.Error(), "could not find the requested resource")
 }
 
+func transformKlusterletAddonConfig(klusterletAddonConfig *agentv1.KlusterletAddonConfig) db.Resource {
+	props := make(map[string]interface{})
+	props["kind"] = "Cluster"
+	props["name"] = klusterletAddonConfig.Spec.ClusterName
+	props["_clusterNamespace"] = klusterletAddonConfig.Spec.ClusterNamespace
+	props["apigroup"] = apigroup // maps rbac to ManagedClusterInfo
+
+	enabledAddons := map[string]interface{}{}
+	enabledAddons["search-collector"] = klusterletAddonConfig.Spec.SearchCollectorConfig.Enabled
+	enabledAddons["policy-controller"] = klusterletAddonConfig.Spec.PolicyController.Enabled
+	enabledAddons["cert-policy-controller"] = klusterletAddonConfig.Spec.CertPolicyControllerConfig.Enabled
+	enabledAddons["application-manager"] = klusterletAddonConfig.Spec.ApplicationManagerConfig.Enabled
+	enabledAddons["iam-policy-controller"] = klusterletAddonConfig.Spec.IAMPolicyControllerConfig.Enabled
+	props["addon"] = enabledAddons // maps to the enabled addons on the cluster
+
+	resource := db.Resource{
+		Kind:           "Cluster",
+		UID:            string("cluster__" + klusterletAddonConfig.Spec.ClusterName),
+		Properties:     props,
+		ResourceString: "managedclusterinfos", // Maps rbac to ManagedClusterInfo
+	}
+	return resource
+}
+
 // Transform ManagedCluster object into db.Resource suitable for insert into redis
 func transformManagedCluster(managedCluster *clusterv1.ManagedCluster) db.Resource {
-	// https://github.com/stolostron/api/blob/main/cluster/v1/types.go#L78
+	// https://github.com/open-cluster-management/api/blob/master/cluster/v1/types.go#L78
 	// We use ManagedCluster as the primary source of information
 	// Properties duplicated between this and ManagedClusterInfo are taken from ManagedCluster
 	props := make(map[string]interface{})
@@ -184,9 +222,9 @@ func transformManagedCluster(managedCluster *clusterv1.ManagedCluster) db.Resour
 	}
 
 	props["kind"] = "Cluster"
-	props["name"] = managedCluster.GetName()                  // must match ManagedClusterInfo
-	props["_clusterNamespace"] = managedCluster.GetName()     // maps to the namespace of ManagedClusterInfo
-	props["apigroup"] = "internal.open-cluster-management.io" // maps rbac to ManagedClusterInfo
+	props["name"] = managedCluster.GetName()              // must match ManagedClusterInfo
+	props["_clusterNamespace"] = managedCluster.GetName() // maps to the namespace of ManagedClusterInfo
+	props["apigroup"] = apigroup                          // maps rbac to ManagedClusterInfo
 	props["created"] = managedCluster.GetCreationTimestamp().UTC().Format(time.RFC3339)
 
 	cpuCapacity := managedCluster.Status.Capacity["cpu"]
@@ -211,14 +249,14 @@ func transformManagedCluster(managedCluster *clusterv1.ManagedCluster) db.Resour
 
 // Transform ManagedClusterInfo object into db.Resource suitable for insert into redis
 func transformManagedClusterInfo(managedClusterInfo *clusterv1beta1.ManagedClusterInfo) db.Resource {
-	// https://github.com/stolostron/multicloud-operators-foundation/
-	//    blob/main/pkg/apis/internal.open-cluster-management.io/v1beta1/clusterinfo_types.go
+	// https://github.com/open-cluster-management/multicloud-operators-foundation/
+	//    blob/master/pkg/apis/internal.open-cluster-management.io/v1beta1/clusterinfo_types.go
 	props := make(map[string]interface{})
 
 	props["kind"] = "Cluster"
 	props["name"] = managedClusterInfo.GetName()
 	props["_clusterNamespace"] = managedClusterInfo.GetNamespace() // Needed for rbac mapping.
-	props["apigroup"] = "internal.open-cluster-management.io"      // Maps rbac to ManagedClusterInfo
+	props["apigroup"] = apigroup                                   // Maps rbac to ManagedClusterInfo
 
 	props["consoleURL"] = managedClusterInfo.Status.ConsoleURL
 	props["nodes"] = int64(len(managedClusterInfo.Status.NodeList))
