@@ -1,4 +1,5 @@
 // Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package clustermgmt
 
@@ -8,9 +9,10 @@ import (
 	"testing"
 
 	sanitize "github.com/kennygrant/sanitize"
-	clusterv1beta1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
+	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
+	agentv1 "github.com/open-cluster-management/klusterlet-addon-controller/pkg/apis/agent/v1"
+	clusterv1beta1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/cluster/v1beta1"
 	"github.com/stretchr/testify/assert"
-	clusterv1 "open-cluster-management.io/api/cluster/v1"
 )
 
 func unmarshalFile(filepath string, resourceType interface{}, t *testing.T) {
@@ -65,3 +67,19 @@ func Test_transformManagedClusterInfo(t *testing.T) {
 	assert.Equal(t, "managedclusterinfos", result.ResourceString, "Test property: ResourceString")
 	assert.Equal(t, "cluster__managed-cluster-01", result.UID, "Test property: UID")
 }
+
+func Test_transformKlusterletAddonConfig(t *testing.T) {
+	klusterletAddonConfig := agentv1.KlusterletAddonConfig{}
+	unmarshalFile("klusterletaddonconfig.json", &klusterletAddonConfig, t)
+
+	result := transformKlusterletAddonConfig(&klusterletAddonConfig)
+
+	assert.Equal(t, result.Kind, "Cluster", "Test Kind")
+	assert.Equal(t, "managed1", result.Properties["name"], "Test property: name")
+
+	assert.Equal(t, "managedclusterinfos", result.ResourceString, "Test property: ResourceString")
+	assert.Equal(t, "cluster__managed1", result.UID, "Test property: UID")
+	testAddons := map[string]interface{}{"application-manager": true, "cert-policy-controller": true,
+		"iam-policy-controller": true, "policy-controller": true, "search-collector": true}
+	assert.Equal(t, testAddons, result.Properties["addon"], "Test property: addon")
+}
