@@ -6,12 +6,13 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 */
 // Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package dbconnector
 
 import (
 	"github.com/golang/glog"
-	"github.com/stolostron/search-aggregator/pkg/config"
+	"github.com/open-cluster-management/search-aggregator/pkg/config"
 	rg2 "github.com/redislabs/redisgraph-go"
 )
 
@@ -35,7 +36,7 @@ type Edge struct {
 // Represents the results of a chunked db operation
 type ChunkedOperationResult struct {
 	ResourceErrors      map[string]error // errors keyed by UID
-	ConnectionError     error            // For when redis conn is down. If this is set, then ResourceErrors and SuccessfulResources are irrelevant.
+	ConnectionError     error            // For when db conn is down. Supersedes ResourceErrors and SuccessfulResources
 	SuccessfulResources int              // Number that were successfully completed
 	EdgesAdded          int
 	EdgesDeleted        int
@@ -84,7 +85,9 @@ func MergeDummyCluster(name string) (*rg2.QueryResult, error) {
 		}
 	}
 
-	query := SanitizeQuery("MERGE (c:Cluster {name: '%s', kind: 'cluster'}) SET c.status = 'OK', c.kubernetesVersion = '%s'", name, kubeVersion)
+	query := SanitizeQuery(
+		"MERGE (c:Cluster {name: '%s', kind: 'cluster'}) SET c.status = 'OK', c.kubernetesVersion = '%s'",
+		name, kubeVersion)
 	return Store.Query(query)
 }
 
