@@ -6,6 +6,7 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 */
 // Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package handlers
 
@@ -15,8 +16,8 @@ import (
 	"time"
 
 	"github.com/golang/glog"
-	"github.com/stolostron/search-aggregator/pkg/config"
-	db "github.com/stolostron/search-aggregator/pkg/dbconnector"
+	"github.com/open-cluster-management/search-aggregator/pkg/config"
+	db "github.com/open-cluster-management/search-aggregator/pkg/dbconnector"
 	rg2 "github.com/redislabs/redisgraph-go"
 )
 
@@ -130,7 +131,8 @@ func buildSubscriptions() (rg2.QueryResult, error) {
 			}
 			if ok {
 				// Add an edge between remoteSub and hubSub.
-				query0 := db.SanitizeQuery("MATCH (hubSub:Subscription {_uid: '%s'}), (remoteSub:Subscription {_uid: '%s'}) CREATE (remoteSub)-[:hostedSub {_interCluster: true,app_instance: %d}]->(hubSub)", hubSubUID, remoteSub[0], currentAppInstance)
+				query0 := db.SanitizeQuery("MATCH (hubSub:Subscription {_uid: '%s'}), (remoteSub:Subscription {_uid: '%s'}) CREATE (remoteSub)-[:hostedSub {_interCluster: true,app_instance: %d}]->(hubSub)",
+					hubSubUID, remoteSub[0], currentAppInstance)
 				resp, err := db.Store.Query(query0)
 				if err != nil {
 					glog.Errorf("Error %s : %s", query, err) //Logging error so that loop will continue
@@ -140,14 +142,16 @@ func buildSubscriptions() (rg2.QueryResult, error) {
 			}
 		}
 		//Delete interclusters with other instance ids after all hub subscriptions are processed
-		deleteOldInstance := db.SanitizeQuery("MATCH ()-[e {_interCluster:true}]->() WHERE (type(e)='hostedSub' OR type(e)='usedBy' OR type(e)='deployedBy') AND e.app_instance<>%d DELETE e", currentAppInstance)
+		deleteOldInstance := db.SanitizeQuery("MATCH ()-[e {_interCluster:true}]->() WHERE (type(e)='hostedSub' OR type(e)='usedBy' OR type(e)='deployedBy') AND e.app_instance<>%d DELETE e",
+			currentAppInstance)
 		_, err = db.Store.Query(deleteOldInstance)
 		if err != nil {
 			return rg2.QueryResult{}, err
 		}
 	} else {
 		//Delete interclusters because there is no remote subscriptions
-		deleteOldInstance := db.SanitizeQuery("MATCH ()-[e {_interCluster:true}]->() WHERE (type(e)='hostedSub' OR type(e)='usedBy' OR type(e)='deployedBy') AND e.app_instance<>%d DELETE e", currentAppInstance)
+		deleteOldInstance := db.SanitizeQuery("MATCH ()-[e {_interCluster:true}]->() WHERE (type(e)='hostedSub' OR type(e)='usedBy' OR type(e)='deployedBy') AND e.app_instance<>%d DELETE e",
+			currentAppInstance)
 		_, err = db.Store.Query(deleteOldInstance)
 		if err != nil {
 			return rg2.QueryResult{}, err
