@@ -7,6 +7,7 @@ irrespective of what has been deposited with the U.S. Copyright Office.
 
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package handlers
 
@@ -18,9 +19,9 @@ import (
 
 	"github.com/golang/glog"
 	"github.com/gorilla/mux"
-	"github.com/stolostron/search-aggregator/pkg/config"
+	"github.com/open-cluster-management/search-aggregator/pkg/config"
 
-	db "github.com/stolostron/search-aggregator/pkg/dbconnector"
+	db "github.com/open-cluster-management/search-aggregator/pkg/dbconnector"
 )
 
 // SyncEvent - Object sent by the collector with the resources to change.
@@ -126,9 +127,10 @@ func SyncResources(w http.ResponseWriter, r *http.Request) {
 		return
 	}
 	response.RequestId = syncEvent.RequestId
-	glog.V(3).Infof("Processing Request { request: %d, add: %d, update: %d, delete: %d edge add: %d edge delete: %d }",
-		syncEvent.RequestId, len(syncEvent.AddResources), len(syncEvent.UpdateResources), len(syncEvent.DeleteResources),
-		len(syncEvent.AddEdges), len(syncEvent.DeleteEdges))
+	glog.V(3).Infof(
+		"Processing Request { request: %d, add: %d, update: %d, delete: %d edge add: %d edge delete: %d }",
+		syncEvent.RequestId, len(syncEvent.AddResources), len(syncEvent.UpdateResources),
+		len(syncEvent.DeleteResources), len(syncEvent.AddEdges), len(syncEvent.DeleteEdges))
 
 	err = db.ValidateClusterName(clusterName)
 	if err != nil {
@@ -139,7 +141,8 @@ func SyncResources(w http.ResponseWriter, r *http.Request) {
 
 	// Validate that we have a Cluster CRD so we can build edges on create
 	if !assertClusterNode(clusterName) {
-		glog.Warningf("Warning, couldn't find a Cluster node with name: %s. This means that the sync request came from a managed cluster that hasn’t joined. Rejecting the incoming sync request.", clusterName)
+		glog.Warningf(
+			"Warning, couldn't find a Cluster node with name: %s. This means that the sync request came from a managed cluster that hasn’t joined. Rejecting the incoming sync request.", clusterName)
 		respond(http.StatusBadRequest)
 		return
 	}
